@@ -19,4 +19,4 @@ class UserDefined:
 
     def window_resized(self):
         """TODO"""
-        self.stdscr.clear()
+        self.screen.clear()
